import argparse
import time
import os
parser = argparse.ArgumentParser(description="your script description")            # description参数可以用于插入描述脚本用途的信息，可以为空
parser.add_argument('--time', '-time', action='store_true', help='verbose mode')   # 添加--verbose标签，标签别名可以为-v，这里action的意思是当读取的参数中出现--verbose/-v的时候


# 参数字典的verbose建对应的值为True，而help参数用于描述--verbose参数的用途或意义。
args = parser.parse_args()
if args.time:
    while True:
        print(time.ctime(),end='\n')





import sys
import os
print(f"Can't import,you can found this path:'{sys.executable[:-10]}Lib\\site-pakages\\downloader-python\\main.py',and then,use python to run it.")
print(os.system(f'{sys.executable} {sys.executable[:-10]}Lib\\site-pakages\\downloader-python\\main.py'))



def load(file_name):
    with open(f'language/{file_name}') as f:
        try:
            return eval(f.read())
        except UnicodeDecodeError:
            with open(f'language/{file_name}',encoding='utf-8') as f:

                return eval(f.read())




import sys
import subprocess
import os
from PyQt5 import *
from PyQt5.Qt import *
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
class Python_stript:
    def __init__(self):
        self.app = QApplication(sys.argv)
        self.windows = QWidget()
        self.windows.setGeometry(300,300,400,400)
        self.windows.setWindowTitle('Python Stript')
        self.grid = QGridLayout()
        self.grid.setSpacing(10)
        self.windows.setLayout(self.grid)

        self.title = QLabel('Python stript')
        self.title.setFont(QFont('Consolas',21))
        self.grid.addWidget(self.title,0,0,1,1)

        self.button = QPushButton("Run")
        self.button.setFont(QFont('Consolas',13))
        self.grid.addWidget(self.button,1,0,1,1)

        self.textedit1 = QTextEdit()
        self.textedit1.setFont(QFont('Consolas',13))
        self.grid.addWidget(self.textedit1,2,0,1,1)

        self.button.clicked.connect(self.run)

        self.windows.show()
        self.app.exec_()

    def run(self):
        t = self.textedit1.toPlainText()
        f = open('test.py','w')
        f.write(t)
        f.close()
        os.system("I:\py3.9\pythonw.exe test.py")
        





from bs4 import BeautifulSoup
import os,sys
import subprocess
def install(moudle=None,index='https://pypi.tuna.tsinghua.edu.cn/simple'):
    pip_path=''

    for i in sys.executable.split('\\')[:-1]:
        pip_path += i + '\\'
    pip_path += 'Scripts\\pip.exe'
    command = f'{sys.executable} {pip_path} install {moudle} -i {index}'
    with open('install.bat','w') as f:
        f.write('@echo off\n'+command)
    subprocess.call('install.bat')
def uninstall(moudle=None):
    pip_path = ''

    for i in sys.executable.split('\\')[:-1]:
        pip_path += i + '\\'
    pip_path += 'Scripts\\pip.exe'
    command = f'{sys.executable} {pip_path} uninstall {moudle}'
    with open('uninstall.bat','w') as f:
        f.write('@echo off\n'+command)
    subprocess.call('uninstall.bat')
def find_moudles():
    pip_path = ''

    for i in sys.executable.split('\\')[:-1]:
        pip_path += i + '\\'
    pip_path += 'Scripts\\pip.exe'
    command = f'{sys.executable} {pip_path} list'
    with open('moudles.bat', 'w') as f:
        f.write('@echo off\n' + command)
    subprocess.call('moudles.bat')


if __name__ == '__main__':
    print(install('pip'))


import turtle
import random

def main():
    turtle.speed(0)
    turtle.hideturtle()
    a={}
    with open('test.pyim','w') as f:
        for i in range(0,160,10):
            for j in range(0,160,10):
                a[str(i)+':'+str(j)] = [random.randint(0,255),
                                       random.randint(0,255),
                                       random.randint(0,255)]
        f.write(str(a))
    with open('test.pyim') as f:
        a = eval(f.read())
    for i in a:
        b = i.split(':')
        turtle.penup()
        
        turtle.goto((int(b[0]),int(b[1])))
        turtle.pendown()
        st = '#'
        
        for j in a[i]:
            
            if len(hex(j)[2:]) < 2:
                
                wdwdw = '0'+hex(j)[2:]
            else:
                wdwdw = hex(j)[2:]
            st+=wdwdw
            print(hex(j)[2:])

        
        turtle.color(st)
        
        turtle.begin_fill()
        for i in range(4):
            
            turtle.left(360/4)
            turtle.forward(10)
        turtle.end_fill()
            
    turtle.color('#000000')
main()



from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.Qt import *
from PyQt5.uic import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
import sys
import requests
import os
import datetime
import time
from colorama import *
from web import *
from PyQt5.Qt import PYQT_VERSION_STR
from PyQt5.QtCore import QT_VERSION_STR
import os
import subprocess
from pip_install import install,uninstall,find_moudles
from load_text import *


init(autoreset=True)

is_Chinese = False
Ui_MainWindow,_ = loadUiType('sources/downloader.ui')
Fast_link,_ = loadUiType('sources/fast_link.ui')
Python_script,_ = loadUiType('sources/python_script.ui')
py_inst,_ = loadUiType('sources/py.ui')

class moudle_installer(QtWidgets.QMainWindow,py_inst):
    def __init__(self):
        super(moudle_installer,self).__init__()
        self.setupUi(self)
        self.pushButton.clicked.connect(self.install)
        self.pushButton_2.clicked.connect(self.uninstall)
        self.pushButton_3.clicked.connect(self.find_moudles)


    def install(self):

        install(self.lineEdit.text())
    def uninstall(self):
        uninstall(self.lineEdit.text())
    def find_moudles(self):
        find_moudles()



class PS(QtWidgets.QMainWindow,Python_script):
    un = pyqtSignal()
    def __init__(self):

        super(PS, self).__init__()
        self.setupUi(self)
        self.pushButton.clicked.connect(self.runs)

    def runs(self):
        self.un.emit()
    def run_script(self):

        s = self.textEdit.toPlainText()
        with open('test.py','w') as f:
            f.write(s)
        with open('run.bat','w') as f:
            f.write('@echo off\n'+f'{sys.executable} test.py')
        subprocess.call('run.bat')

class Fast(QtWidgets.QMainWindow,Fast_link):
    a = pyqtSignal()
    b = pyqtSignal()
    def __init__(self):

        super(Fast, self).__init__()
        self.setupUi(self)
        self.pushButton.clicked.connect(self.a.emit)
        self.pushButton_2.clicked.connect(self.b.emit)
        self.main_timer = QtCore.QTimer()
        self.main_timer.timeout.connect(self.loadd)
        self.main_timer.start(1)



    def load(self,dic):


        self.label.setText(dic['fastlink.label'])
        self.pushButton.setText(dic['fastlink.pushButton'])
        self.pushButton_2.setText(dic['fastlink.pushButton_2'])

    def loadd(self):
        if is_Chinese:
            self.load(load('zh-cn.lang'))
        else:
            self.load(load('en-us.lang'))






class window(QtWidgets.QMainWindow,Ui_MainWindow):
    signal = pyqtSignal()
    fast_link = pyqtSignal()
    version = '1.8pre5'
    def __init__(self):




        super(window,self).__init__()
        with open('log/log.log', 'w') as f:
            f.write('')
        self.log(f'[{time.ctime()}][main/Info] loading')

        self.user_name = ''
        while True:
            self.user_name = input('Your name is:')
            if self.user_name != '':
                break
            else:
                self.log(f'[{time.ctime()}][main/WARN] user name is Null,please try again',color=Fore.YELLOW)

        self.log(f'[{time.ctime()}][main/INFO] Setting user:{self.user_name}')

        self.setupUi(self)
        self.pushButton.clicked.connect(self.download)
        self.te = ''
        self.progressBar.setValue(0)
        self.pushButton_2.clicked.connect(self.fwa)
        self.pushButton_3.clicked.connect(self.fast)
        self.wdw = ''



        self.setWindowIcon(QIcon('sources/icon.bmp'))
        self.log(f'[{time.ctime()}][main/Info] icon loaded')

        try:
            self.load()
            self.log(f'[{time.ctime()}][main/Info] load settings.properties sucsess')
        except BaseException as e:


            self.log(f'[{time.ctime()}][main/Error] error in initlazing:{e}',Fore.RED)

            self.log(r'*\**:( Downloader Crashed! ):**/*',Fore.RED)
            sys.exit(self.show())

        self.timer = QTimer()
        self.timer.timeout.connect(self.write)
        self.timer.start(1)
        self.log(f'[{time.ctime()}][main/Info] timer initlazing sucsess')
        self.log(
            f'[{time.ctime()}][main/Info] backend library:PyQt5 version {PYQT_VERSION_STR} build on Qt {QT_VERSION_STR}')


    def loadt(self,dic):

        self.groupBox.setTitle(dic['groupBox'])
        self.label.setText(dic['label'])
        self.label_2.setText(dic['label_2'])
        self.pushButton.setText(dic['pushButton'])
        self.groupBox_2.setTitle(dic['groupBox_2'])
        self.label_3.setText(dic['label_3'])
        self.label_4.setText(dic['label_4'])
        self.pushButton_2.setText(dic['pushButton_2'])
        self.label_5.setText(dic['label_5']+self.version)
        self.groupBox_3.setTitle(dic['groupBox_3'])
        self.checkBox.setText(dic['checkBox'])
        self.groupBox_4.setTitle(dic['groupBox_4'])
        self.checkBox_2.setText(dic['checkBox_2'])
        self.checkBox_3.setText(dic['checkBox_3'])
        self.groupBox_5.setTitle(dic['groupBox_5'])
        self.groupBox_6.setTitle(dic['groupBox_6'])
        self.pushButton_3.setText(dic['pushButton_3'])
        self.setWindowTitle(self.user_name+dic['title'])
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), dic['tab_win.tab'])
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), dic['tab_win.tab_2'])
        self.tabWidget_2.setTabText(self.tabWidget.indexOf(self.tab), dic['tab_win2.tab'])
        self.tabWidget_2.setTabText(self.tabWidget.indexOf(self.tab_2), dic['tab_win2.tab_2'])
        self.checkBox_4.setText(dic['checkBox_4'])

    def fast(self):
        self.log(
            f'[{time.ctime()}][main/Info] fast link started')
        self.fast_link.emit()
    def log(self,text,color=Fore.RESET):
        print(color+text)
        try:
            self.wdw += '\n' + text
            self.textBrowser_2.setText(self.wdw)
        except BaseException:
            self.wdw = ''
            self.wdw += text + '\n'
            self.tab_4 = QtWidgets.QWidget()
            self.tab_4.setObjectName("tab_4")
            self.textBrowser_2 = QtWidgets.QTextBrowser(self.tab_4)
            self.textBrowser_2.setGeometry(QtCore.QRect(5, 1, 761, 221))
            self.textBrowser_2.setObjectName("textBrowser_2")
            self.textBrowser_2.setText(self.wdw)
        with open('log/log.log','a') as f:
            f.write(text+'\n')

    def opencmd(self):
        os.system('cmd')
    def fwa(self):
        self.close()
    def print(self):
        self.log(f'[{time.ctime()}][main/Info] stopping!')

    def load(self):

        a = open('properties/settings.properties')

        dicss = a.read()
        dicss = eval(dicss)


        if dicss['no useragent']:
            self.checkBox.toggle()
        if dicss['no speed']:
            self.checkBox_2.toggle()
        if dicss['no error']:
            self.checkBox_3.toggle()
        self.lineEdit.setText(dicss['url'])
        self.lineEdit_2.setText(dicss['locate'])
        if dicss['Chinese']:
            is_Chinese == True
            self.checkBox_4.toggle()

    def closeEvent(self,event):
        if is_Chinese:
            result = QtWidgets.QMessageBox.question(self,'关闭','是否关闭?',QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
        else:
            result = QtWidgets.QMessageBox.question(self, 'close', 'Close?',
                                                    QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
        if result == QtWidgets.QMessageBox.Yes:
            self.print()
            event.accept()

        else:
            event.ignore()
    def write(self):
        self.timer.stop()
        self.timer.start(self.horizontalSlider.value())
        if self.checkBox_4.isChecked():
            self.lang = load('zh-cn.lang')
            self.loadt(self.lang)
            is_Chinese == True


        else:
            self.lang = load('en-us.lang')
            self.loadt(self.lang)
            is_Chinese == False


        a = open('properties/settings.properties','w')
        #dic = [None,None,None,None,None,None]
        dics = {'no useragent':None,
               'no speed':None,
               'no error':None,
               'url':None,
               'locate':None,
               'Chinese':None}

        dics['no useragent'] = self.checkBox.isChecked()
        dics['no speed'] = self.checkBox_2.isChecked()
        dics['no error'] = self.checkBox_3.isChecked()
        dics['url'] = self.lineEdit.text()
        dics['locate'] = self.lineEdit_2.text()
        dics['Chinese'] = self.checkBox_4.isChecked()




        a.write(str(dics))


    def download(self):
        self.log(f'[{time.ctime()}][main/Info] Downloading')
        self.u(0)
        a = datetime.datetime.now()
        self.u(1)
        self.te = ''
        self.u(3)
        self.textBrowser.setText(self.te)
        self.u(4)
        self.update('initlazing')
        self.u(5)

        try:
            self.u(10)
            self.update('getting')
            self.u(20)
            if not self.checkBox.isChecked():
                if self.lineEdit_3.text() == '':
                    header = {'user-agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.159 Safari/537.36 Edg/92.0.902.78'}
                else:
                    header = header = {'user-agent':self.lineEdit_3.text()}

                r = requests.get(self.lineEdit.text(),headers = header)
            else:
                r = requests.get(self.lineEdit.text())
            self.u(30)
            con = r.content
            self.u(40)
            text = self.lineEdit.text().split('/')
            self.u(50)
            self.update('downloading')
            self.u(60)
            if self.lineEdit_2.text() != '':
                aaaaa = self.lineEdit_2.text()+'/'+text[-1].replace('/','')\
            .replace(r'\\', '')\
            .replace(':', '')\
            .replace('*', '')\
            .replace('?', '')\
            .replace('"','') \
            .replace('<', '') \
            .replace('>', '') \
            .replace('|', '')
            else:
                aaaaa = text[-1].replace('/', '') \
                    .replace(r'\\', '') \
                    .replace(':', '') \
                    .replace('*', '') \
                    .replace('?', '') \
                    .replace('"', '') \
                    .replace('<', '') \
                    .replace('>', '') \
                    .replace('|', '')


            aaa = str(time.time())
            with open(aaaaa,'ab+') as f:
                self.u(70)
                self.update('writing')
                self.u(80)
                f.write(con)
                self.u(90)
            self.u(101)
            b = datetime.datetime.now()
            x = b-a
            x = x.total_seconds()
            if not self.checkBox_2.isChecked():
                print(f'[{time.ctime()}][main/Info] Download from {self.lineEdit.text()} sucsess')
                size = float(os.path.getsize(aaaaa))
                if size >= 1024 and size <= 1024*1024:
                    self.update(f'sucsess in {x}s({size/1024}KB,{size/1024/x}KB/s)')
                elif size >= 1024*1024 and size <= 1024*1024*1024:
                    self.update(f'sucsess in {x}s({size/1024/1024}MB,{size/1024/1024/x}MB/s)')
                elif size >= 1024*1024*1024 and size <= 1024*1024*1024*1024:
                    self.update(f'sucsess in {x}s({size/1024/1024/1024}GB,{size/1024/1024/1024/x}GB/s)')
                elif size >= 1024*1024*1024*1024:
                    self.update(f'sucsess in {x}s({size/1024/1024/1024/1024}TB,{size/1024/1024/1024/1024/x}TB/s)')
                else:
                    self.update(f'sucsess in {x}s({size}B,{size/x}B/s)')
            else:
                self.update(f'sucsess in {x}s')
                self.log(f'[{time.ctime()}][main/Info] Download from {self.lineEdit.text()} sucsess')

        except BaseException as e:
            self.u(0)
            if not self.checkBox_3.isChecked():
                self.update(f'error:{e}')
            else:
                self.update(f'failed')


            self.log(f'[{time.ctime()}][main/Warn] error in download:{e},ignored',Fore.YELLOW)







    def update(self,t):
        self.te += t + '\n'
        self.textBrowser.setText(self.te)
    def u(self,v):
        a = self.progressBar.value()
        if v > a:
            for i in range(a,v):
                self.progressBar.setValue(i)
                time.sleep(0.001)
        else:

            self.progressBar.setValue(v)
class Main:
    def __init__(self):
        self.app = QtWidgets.QApplication(sys.argv)
        self.d = moudle_installer()
        self.a = PS()
        self.fast = Fast()
        self.window = window()
    def connect_windows(self):
        self.a.un.connect(self.a.run_script)

        self.fast.a.connect(self.a.show)
        self.fast.b.connect(self.d.show)
        self.window.fast_link.connect(self.fast.show)
    def run(self):
        self.window.show()
        sys.exit(self.app.exec_())
if __name__ == '__main__':
    main = Main()
    main.connect_windows()
    main.run()






else:
    print(f'[{time.ctime()}][main/Info] now varbile "__name__"={__name__},run in web mode')
    run('1.3')






import sys
from PyQt5 import *
from PyQt5.Qt import *
from PyQt5.QtGui import *
from PyQt5.QtWidgets import *
from PyQt5.QtCore import *

class HTML_creater:
  def __init__(self):
    self.app = QApplication(sys.argv)
    self.windows = QWidget()
    self.windows.setGeometry(300,300,400,400)
    self.windows.setWindowTitle('HTML creater')
    self.grid = QGridLayout()
    self.grid.setSpacing(10)
    self.windows.setLayout(self.grid)

    self.label1 = QLabel('HTML creater')
    self.label1.setFont(QFont('Consolas',21))
    self.grid.addWidget(self.label1,0,0,1,2)

    self.pushbutton1 = QPushButton("HTML")
    self.pushbutton1.setFont(QFont('Consolas',13))
    self.grid.addWidget(self.pushbutton1,1,0,1,2)

    self.textedit1 = QTextEdit()
    self.textedit1.setFont(QFont('Consolas',13))
    self.grid.addWidget(self.textedit1,2,0,1,1)

    self.textedit2 = QTextEdit()
    self.textedit2.setFont(QFont('Consolas',13))
    self.grid.addWidget(self.textedit2,2,1,1,1)

    
    self.pushbutton1.clicked.connect(self.HTML)
    self.windows.show()
    self.app.exec_()

  def HTML(self):
    self.t = self.textedit1.toPlainText()
    self.textedit2.setHtml(self.t)





import sys
import subprocess
import os
from PyQt5 import *
from PyQt5.Qt import *
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from easygui import *
import cv2
import numpy as np
from tkinter import *
import time

class Media_player:
    def __init__(self):
        self.app = QApplication(sys.argv)
        self.windows = QWidget()
        self.windows.setGeometry(300, 300, 400, 400)
        self.windows.setWindowTitle('Media player')
        self.grid = QGridLayout()
        self.grid.setSpacing(10)
        self.windows.setLayout(self.grid)

        self.lb1 = QLabel("Media player")
        self.lb1.setFont(QFont('Consolas',21))
        self.grid.addWidget(self.lb1,0,0,1,1)

        self.pushButton1 = QPushButton("Open file")
        self.pushButton1.setFont(QFont('Consolas',13))
        self.grid.addWidget(self.pushButton1,1,0,1,1)

        self.pushButton1.clicked.connect(self.play)

        self.windows.show()
        self.app.exec_()
        


    def play(self):
        file, filetype = QFileDialog.getOpenFileName(self.windows,
                  "Choose files",
                  "./",
                  "MP4 Files (*.mp4);;MOV Files (*.mov)")
        self.aa = Tk()
        self.lbl100000000 = Label(self.aa, text="Loading...", font=("Consolas", 13))
        self.lbl100000000.grid(column=0,row=0)
        self.aa.mainloop()
        
        
        cap = cv2.VideoCapture(file)

        while (cap.isOpened()):
            ret, frame = cap.read()
            cv2.imshow('frame', frame)
            if cv2.waitKey(40) & 0xFF == ord('q'):
                break

        cap.release()
        cv2.destroyAllWindows()


        









from setuptools import setup
version = '1.8pre5'
print(f'version:{version}')
with open('README.md','r',encoding='utf-8') as f:
    long_description = f.read()
setup(
    name='downloader-python',
    version=version,
    url='https://github.com',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='mc_creater',
    author_email='guoxiuchen20170402@163.com',
    license='MIT',
    packages=['downloader-python','command','pyim','exes','doge'],
    classifiers=['Programming Language :: Python :: 3.6',
                 'Programming Language :: Python :: 3.7',
                 'Programming Language :: Python :: 3.8',
                 'Programming Language :: Python :: 3.9',],
    python_requires='>=3.6',
    install_requires=['turtle','PyQt5','requests','bs4','lxml',],
    include_package_data=True

)


import sys
from PyQt5 import *
from PyQt5.Qt import *
from PyQt5.QtGui import *
from PyQt5.QtWidgets import *
from PyQt5.QtCore import *

class Text_creater:
  def __init__(self):
    self.app = QApplication(sys.argv)
    self.windows = QWidget()
    self.windows.setGeometry(300,300,400,400)
    self.windows.setWindowTitle('Text creater')
    self.grid = QGridLayout()
    self.grid.setSpacing(10)
    self.windows.setLayout(self.grid)

    self.textedit1 = QTextEdit()
    self.textedit1.setFont(QFont('Consolas',13))
    self.grid.addWidget(self.textedit1,2,0,1,3)

    self.label2 = QLabel('')
    self.label2.setFont(QFont('Consolas',13))
    self.grid.addWidget(self.label2,3,0,1,1)

    self.timer = QTimer(self.app)
    self.timer.timeout.connect(self.get_number)
        
    self.timer.start(1)

    self.label1 = QLabel('Text creater')
    self.label1.setFont(QFont('Consolas',21))
    self.grid.addWidget(self.label1,0,0,1,1)





    


    
    



    
   
    
    
    
    
    self.windows.show()
    self.app.exec_()





    
        
  def get_number(self):
   
    self.label2.setText(f"text number:{str(len(self.textedit1.toPlainText()))}")


    

    



import pyecharts.options as opts

import pandas as pd
from pyecharts.charts import *
from pyecharts.globals import CurrentConfig, NotebookType
import sys
from PyQt5 import *
from PyQt5.Qt import *
from PyQt5.QtGui import *
from PyQt5.QtWidgets import *
from PyQt5.QtCore import *


class Charts_render:
    def __init__(self):
        CurrentConfig.NOTEBOOK_TYPE = NotebookType.JUPYTER_NOTEBOOK
        self.d = []
        self.ds = []
        self.dz = []
        self.fs = []
        
        self.app = QApplication(sys.argv)
        self.windows = QWidget()
        self.windows.setGeometry(300,300,400,600)
        self.windows.setWindowTitle('Charts Render')
        self.grid = QGridLayout()
        self.grid.setSpacing(10)
        self.windows.setLayout(self.grid)

        self.title1 = QLabel('Charts Render')
        self.title1.setAlignment(Qt.AlignCenter)
        self.title1.setFont(QFont('Consolas',45))
        self.grid.addWidget(self.title1,0,0,1,1)
        
        self.pushButton1 = QPushButton("Open file")
        self.pushButton1.setFont(QFont('Consolas',13))
        self.grid.addWidget(self.pushButton1,1,0,1,1)

        self.pushButton2 = QPushButton("Sure")
        self.pushButton2.setFont(QFont('Consolas',13))
        self.grid.addWidget(self.pushButton2,1,1,1,1)

        self.pushButton3 = QPushButton("Clear")
        self.pushButton3.setFont(QFont('Consolas',13))
        self.grid.addWidget(self.pushButton3,1,2,1,1)

        self.lbl = QLabel('Output path:')
        self.lbl.setFont(QFont('Consolas',13))
        self.grid.addWidget(self.lbl,2,0,1,1)

        self.inp = QLineEdit()
        self.inp.setFont(QFont('Consolas',13))
        self.grid.addWidget(self.inp,2,1,1,2)

        self.info1 = QTextBrowser()
        self.info1.setFont(QFont('Consolas',13))
        self.grid.addWidget(self.info1,3,0,1,3)
        self.t = ''

        
                
        

        self.pushButton1.clicked.connect(self.get_file)
        self.pushButton2.clicked.connect(self.main)
        self.pushButton3.clicked.connect(self.clear)
        self.windows.show()
        self.app.exec_()
        
        

    def clear(self):
        self.t = ''
        self.info1.setText(self.t)
        
        
    def main(self):
        try:
            try:
                self.t = ''
                self.info1.setText(self.t)

            
            
            
            
                self.open_file(self.ff)
                self.t += f'Open success\n'
                self.info1.setText(self.t)
            
            
                self.file_style()
                self.t += f'Data styled\n'
                self.info1.setText(self.t)
                
                
                self.model()
                self.t += f'Charts model created\n'
                self.info1.setText(self.t)
                
                
                self.render()
                self.t += f'render seccess\n'
                self.info1.setText(self.t)
            except AssertionError:
                self.t = ''
                self.info1.setText(self.t)
                self.t += 'File open failed'
                self.info1.setText(self.t)
        except AttributeError:
            self.t = ''
            self.info1.setText(self.t)
            self.t += 'File open failed'
            self.info1.setText(self.t)
        
    
    def get_file(self):
        self.t = ''
        self.info1.setText(self.t)
        openfile_name = QFileDialog.getOpenFileName(self.windows,'Choose files','','Excel files(*.xlsx , *.xls)')
        self.t += f"Choose:'{openfile_name[0]}'\n"
        self.info1.setText(self.t)
        self.ff = openfile_name[0]

    
    def open_file(self,f):
        
        self.pdf = pd.read_excel(f)
        
    def file_style(self):
        self.index = []
        self.value = []
        for i in self.pdf:
            self.index.append(i)
            
        for i in range(len(self.index)):
            self.value.append([])
            for j in self.pdf[self.index[i]]:
                self.value[i].append(j)

        
                
        
    
    def model(self):
        self.bar = Line(init_opts=opts.InitOpts(theme='dark',animation_opts=opts.AnimationOpts(animation_delay=500, animation_easing="elasticOut"),width="1400px", height="600px"))
        
        for i in range(len(self.value)):
            if self.index[i] == 'date':
                self.bar.add_xaxis(self.value[i])
            else:
                self.bar.add_yaxis(self.index[i], self.value[i],is_connect_nones=True,is_smooth=True,label_opts = opts.LabelOpts(is_show=False))
        
        
        self.bar.set_series_opts(label_opts=opts.LabelOpts(is_show=False))
    def render(self):
        self.bar.render(self.inp.text())



    






from tkinter import *
from charts_render import *
from textcreater import *
from htmlcreater import *
from python_stript import *
from media_player import *
import os
import subprocess
import time
import sys
from datetime import datetime
from PIL import Image,ImageTk


class Init_OS:
    def __init__(self):
        pass
    def init(self):



        self.btn_list = []
        for i in range(10):
            self.btn_list.append([])
        for i in range(10):
            for j in range(10):
                self.btn_list[i].append([])
        return self.btn_list

        



class DogHead_OS:

    version = 'DogHead OS beta 0.1.7'
    icon_path = 'icon.ico'

    msettings = open('/settings/main.setting')
    msettings = eval(msettings.read())


    def __init__(self):



        self.window = Tk()
        self.window.title("DogHead OS")
        self.window.iconbitmap(self.icon_path)

        self.l = Label(self.window, text="", font=("Consolas", 20))
        self.l.grid(column=0, row=0)
        self.f()
        

        self.window.mainloop()


        
        
        self.window = Tk()
        self.window.title("DogHead OS")
        self.window.iconbitmap(self.icon_path)
        
        
        self.btn_list = Init_OS().init()
        for i in range(10):
            for j in range(10):
                self.btn_list[i][j] = Button(self.window, text="None", command=None, font=("Consolas", 13))
                self.btn_list[i][j].grid(column=j, row=i+1)

        self.btn_name = ["Charts Render","explorer",
                    "text creater", "HTML creater",
                    "Settings","Close",
                         "notepad","regedit",
                         "command","calc",
                         "PCL2","Python stript",
                         "Media player"]
        self.btn_commands = [self.app1,self.app2,
                        self.app3,self.app4,
                        self.set1,self.cl,
                        self.app6,self.app7,
                        self.app8,self.app9,
                        self.app10,self.app11,
                        self.app12]
        self.index = 0
        self.y = 0

        
        for i in zip(self.btn_name,self.btn_commands):
            self.btn_list[self.y][self.index] = Button(self.window, text=i[0], command=i[1], font=("Consolas", 13))
            self.btn_list[self.y][self.index].grid(column=self.y, row=self.index+1)
            if self.index == 9:
                self.index = 0
                self.y += 1
            else:
                self.index += 1

            if self.y == 9 and self.index == 9:
                
                continue
        
        self.lbl100000000 = Label(self.window, text="D", font=("Consolas", 50))
        self.lbl100000000.grid(column=0,row=0)
        self.lbl100000001 = Label(self.window, text="o", font=("Consolas", 50))
        self.lbl100000001.grid(column=1,row=0)
        self.lbl100000002 = Label(self.window, text="g", font=("Consolas", 50))
        self.lbl100000002.grid(column=2,row=0)
        self.lbl100000003 = Label(self.window, text="H", font=("Consolas", 50))
        self.lbl100000003.grid(column=3,row=0)
        self.lbl100000004 = Label(self.window, text="e", font=("Consolas", 50))
        self.lbl100000004.grid(column=4,row=0)
        self.lbl100000005 = Label(self.window, text="a", font=("Consolas", 50))
        self.lbl100000005.grid(column=5,row=0)
        self.lbl100000006 = Label(self.window, text="d", font=("Consolas", 50))
        self.lbl100000006.grid(column=6,row=0)
        self.lbl100000007 = Label(self.window)
        self.lbl100000007.grid(column=7,row=0)
        img_open = Image.open('icon (2).gif')
        img=ImageTk.PhotoImage(img_open)
        self.lbl100000007.config(image=img)
        
        self.lbl100000008 = Label(self.window, text="O", font=("Consolas", 50))
        self.lbl100000008.grid(column=8,row=0)
        self.lbl100000009 = Label(self.window, text="S", font=("Consolas", 50))
        self.lbl100000009.grid(column=9,row=0)
        
        
                
        self.lbl4 = Label(self.window, text="", font=("Consolas", 13))
        self.lbl4.grid(column=11, row=11)
        self.refresh()
        self.is_timing = False

        self.window.mainloop()
    def f(self):
        self.window.after(100,self.d)
        
        
        
    def d(self):
        for i in range(10):
            for j in range(4):
                
                self.l = Label(self.window, text="Welcome"+i*'.', font=("Consolas", 20))
                self.l.grid(column=0, row=0)
        


        
        
    def cl(self):
        self.window.destroy()
    
    def refresh(self):
        self.app5()
        self.window.after(1,self.refresh)
        
    

    def app1(self):
        a = Charts_render()
    def app2(self):
        subprocess.call('C:/Windows/explorer.exe')
    def app3(self):
        b = Text_creater()
    def app4(self):
        c = HTML_creater()
    def app5(self):
        #print(type(self.msettings))
        if self.msettings['time_mode'] == 'time mode 1':
            self.lbl4['text'] = time.ctime()
        if self.msettings['time_mode'] == 'time mode 2':
            self.lbl4['text'] = time.strftime('%Y-%m-%d %H:%M:%S')
        if self.msettings['time_mode'] == 'time mode 3':
            self.lbl4['text'] = round(time.time(),1)
    def app6(self):
        subprocess.call('C:/Windows/notepad.exe')
    def app7(self):
        subprocess.call("C:/Windows/regedit.exe")
    def app8(self):
        os.system('cmd')
    def app9(self):
        subprocess.call("C:/Windows/System32/calc.exe")

    def app10(self):
        subprocess.call("Plain Craft Launcher 2.exe")
    def app11(self):
        a = Python_stript()
    def app12(self):
        a = Media_player()
    def set1(self):
            
        self.settings = Tk()
        self.settings.title("DogHead OS Settings")
        self.lbl100 = Label(self.settings, text=f"Version:{self.version}", font=("Consolas", 21))
        self.lbl100.grid(column=0, row=0)
        self.btn = Button(self.settings, text="about", command=self.set2, font=("Consolas", 13))
        self.btn.grid(column=0, row=1)
        self.btn7 = Button(self.settings, text="time set", command=self.set3, font=("Consolas", 13))
        self.btn7.grid(column=0, row=2)
            
        self.settings.mainloop()
    def set2(self):
        self.about = Tk()
        self.about.title("About")
        self.lbl3 = Label(self.about, text='writers e-mail:guoxiuchen20170402@163.com\npython:3.9.5\nlibs:PyQt5,Tkinter', font=("Consolas", 13))
        self.lbl3.grid(column=0, row=0)

        self.about.mainloop()
    def set3(self):
        self.time = Tk()
        self.time.title("time set")
        self.lbl6 = Label(self.time, text='Time', font=("Consolas", 21))
        self.lbl6.grid(column=0, row=0)

        self.lbl5 = Label(self.time, text='Time Mode:', font=("Consolas", 16))
        self.lbl5.grid(column=0, row=1)

        self.btn2 = Button(self.time, text="time mode 1", command=self.set4, font=("Consolas", 13))
        self.btn2.grid(column=1, row=2)
        self.btn3 = Button(self.time, text="time mode 2", command=self.set5, font=("Consolas", 13))
        self.btn3.grid(column=1, row=3)
        self.btn3 = Button(self.time, text="time mode 3", command=self.set6, font=("Consolas", 13))
        self.btn3.grid(column=1, row=4)
        

        self.lbl7 = Label(self.time, text=f"Now time Mode:{self.msettings['time_mode']}", font=("Consolas", 16))
        self.lbl7.grid(column=1, row=5)
        
        self.time.mainloop()
    def set4(self):
        self.time_format = 'time mode 1'
        self.lbl7['text'] = f'Now time Mode:{self.time_format}'
        self.msettings['time_mode'] = 'time mode 1'
        open('/settings/main.setting','w').write(str(self.msettings))
        msettings = open('/settings/main.setting')
        msettings = eval(msettings.read())
        

            
    def set5(self):
        self.time_format = 'time mode 2'
        self.lbl7['text'] = f'Now time Mode:{self.time_format}'
        self.msettings['time_mode'] = 'time mode 2'
        open('/settings/main.setting','w').write(str(self.msettings))
        msettings = open('/settings/main.setting')
        msettings = eval(msettings.read())

    def set6(self):
        self.time_format = 'time mode 3'
        self.lbl7['text'] = f'Now time Mode:{self.time_format}'
        self.msettings['time_mode'] = 'time mode 3'
        open('/settings/main.setting','w').write(str(self.msettings))
        msettings = open('/settings/main.setting')
        msettings = eval(msettings.read())
    

a = DogHead_OS()
#This is a test.


    


